module.exports = function(grunt) {
  var nightwatch = require('nightwatch');
  nightwatch.initGrunt(grunt);
  grunt.initConfig({
    pkg: grunt.file.readJSON('package.json'),
    concat: {
      options: {
        separator: ';'
      },
      dist: {
        src: ['public/js/*.js'],
        dest: 'public/dist/<%= pkg.name %>.js'
      }
    },
    uglify: {
      options: {
        banner: '/*! <%= pkg.name %> <%= grunt.template.today("dd-mm-yyyy") %> */\n'
      },
      dist: {
        files: {
          'public/dist/<%= pkg.name %>.min.js': ['<%= concat.dist.dest %>']
        }
      }
    },
    qunit: {
      files: ['qunit/**/*.html']
    },
    jshint: {
      files: ['Gruntfile.js', 'app.js', 'public/js/*.js', 'routes/*.js',
        '!public/js/admin.js', '!public/js/harkdesigner.js', '!public/js/login.js', '!routes/multiuser.js'],
      options: {
        // options here to override JSHint defaults
        //unused: true,
        undef: true,
        laxcomma: true,
        laxbreak: true,
        browser : true,
        dojo:  true,
        devel: true,
        node: true,
        jquery: true,
        globals: {
          jQuery: false,
//          console: true,
//          module: true,
//          document: true
          _: false,
          Backbone: false,
          Backgrid: false,
          introJs: false,
          selenium: true
        },
      }
    },
    watch: {
      files: ['<%= jshint.files %>'],
      tasks: ['jshint', 'qunit']
    },
    compass: {
      dist: {
          options: {
             config: 'public/config.rb'
          }
      }
    },
    cssmin: {
      compress: {
        files: {
          "public/dist/main.min.css": ["public/stylesheets/main.css"]
        }
      }
    },
    nightwatch: {
      options: {
        // task options
        standalone: false,
        // download settings
        // jar_version: '2.53.1',
        // jar_path: 'automated-tests/node_modules/selenium-server/lib/runner/selenium-server-standalone-2.53.1.jar',
        // jar_url: 'http://domain.com/files/selenium-server-standalone-1.2.3.jar',
        output_folder: "automated-tests/reports",
        page_objects_path: "automated-tests/lib/pages",
        src_folders: ['automated-tests/tests'],
        test_settings: {
          default: {
            desiredCapabilities: {
              browserName: "chrome"
            },
            // cli_args : {
            //   "webdriver.chrome.driver" : "automated-tests/node_modules/chromedriver/lib/chromedriver/chromedriver.exe"
            // },
            screenshots: {
              enabled: true,
              on_failure: true,
              path: "automated-tests/screenshots"
            },
          }
        }
      }
    },
    express: {
      options: {
        script: 'app.js',
        //background: false,
        debug: true,
        output: "defs loaded"
      },
      dev: {

      }
    },
    plato: {
      options: {
        jshint: '<%= jshint.options %>',
        complexity: {
          logicalor: true,
          switchcase: true,
          forin: true,
          trycatch: true,
          newmi: true
        }
      },
      dist: {
        files: {
          'docs/report/plato': ['app.js', 'public/js/*.js', 'routes/*.js',
            '!public/js/admin.js', '!public/js/harkdesigner.js', '!public/js/login.js', '!routes/multiuser.js']
        }
      }
    },
    complexity: {
      generic: {
        src: ['Gruntfile.js', 'app.js', 'public/js/*.js', 'routes/*.js',
          '!public/js/admin.js', '!public/js/harkdesigner.js', '!public/js/login.js', '!routes/multiuser.js'],
        options: {
          breakOnErrors: true,
          jsLintXML: 'docs/report/complexity/report.xml',
          //checkstyleXML: 'checkstyle.xml',
          //pmdXML: 'pmd.xml',
          errorsOnly: false,
          cyclomatic: [3, 7, 12],
          halstead: [8, 13, 20],
          maintainability: 100,
          hideComplexFunctions: false,
          broadcast: false
        }
      }
    }
  });

  grunt.loadNpmTasks('grunt-contrib-compass');
  grunt.loadNpmTasks('grunt-contrib-cssmin');
  grunt.loadNpmTasks('grunt-contrib-uglify');
  grunt.loadNpmTasks('grunt-contrib-jshint');
  grunt.loadNpmTasks('grunt-contrib-qunit');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-contrib-concat');
  grunt.loadNpmTasks('grunt-plato');
  grunt.loadNpmTasks('grunt-complexity');
  grunt.loadNpmTasks('grunt-express-server');
  grunt.loadNpmTasks('grunt-nightwatch');

  grunt.registerTask('test', ['jshint', 'qunit']);
  grunt.registerTask('automated-test', ['express' ,'nightwatch']);

  grunt.registerTask('metrics', ['plato', 'complexity']);

  grunt.registerTask('default', ['jshint', 'qunit', 'concat', 'compass', 'cssmin', 'uglify']);

};
