var async    = require('async');
var canvass;
module.exports = {
    '@tags': ['cf_createSheet'],
    before: function (client) {
        client
            .url(client.launchUrl)
            .waitForElementVisible('body', 1000);
    },

    after: function (client) {

        client.end();
    },
    /**
     *  Test: 3-001
     *  Expects:
     *      - Hark Designer should load.
     *      - File Manager dialog will appear
     *      - Network should be loaded.
     */
    "3-001": function (client) {
        async.series([
                //load HARK Designer
                function (callback) {
                    canvass = client.page.canvass();
                    canvass.navigate();

                    //check if body is now visible
                    canvass.expect.element('body').to.be.present;

                    //should have Main sheet
                    canvass.expect.element('@mainSheet').to.be.visible;
                    callback();
                },
                //load a network file
                function (callback) {
                    canvass.loadFixture(client, function () {
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 3-002
     *  Expects:
     *      - Context menu will be displayed.
     */
    "3-002": function (client) {
        async.series([
                //select Main Sheet
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        callback();
                    });
                },
                //right click on Node nodeConstant1
                function (callback) {
                    client
                        .moveToElement('#node_Constant_1', 0, 0)
                        .mouseButtonClick('right', function() {
                            callback();
                    });
                },
                //check if context menu is displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 2000, function(){
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 3-003
     *  Expects:
     *      - "Add a new sheet" dialog will be displayed.
     *      - Dialog should contain the following fields:
     *          - Name
     *          - Type: (subnet/iterator)
     */
    "3-003": function (client) {
        async.series([
                // Wait for "Create Sheet from selected" option
                function (callback) {
                    canvass.waitForElementPresent('@createSheetFromNodeOption', 2000, function () {
                        callback();
                    });
                },
                // click "Create Sheet from selected" option
                function (callback) {
                    canvass.click('@createSheetFromNodeOption', function () {
                        callback();
                    });
                },
                //wait for the dialog to be displayed
                function (callback) {
                    canvass.waitForElementVisible('@addSheetDialog', 1000, function(){
                        callback();
                    });
                },
                //check if name and type fields are present
                function (callback) {
                    canvass.expect.element('@sheetName').to.be.visible;
                    canvass.expect.element('@sheetType').to.be.visible;

                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 3-004
     *  Expects:
     *      - "Add a new sheet" should close and new sheet will be added in the tab panel.
     *      - There should be an error if the set name is already exists.
     *      - Selected node should be drawn in the new sheet.
     */
    "3-004": function (client) {
        async.series([
                // Set value of new sheet
                function (callback) {
                    canvass.setValue('@sheetName', 'test1', function () {
                       callback();
                    });
                },
                // click submit button
                function (callback) {
                    canvass.click('@addSheetSubmitButton', function(){
                        callback();
                    });
                },
                //wait for the dialog to be closed
                function (callback) {
                    canvass.waitForElementNotVisible('@addSheetDialog', 1000, function () {
                        callback();
                    });
                },
                //validate results
                function (callback) {
                    //dialog should be closed
                    canvass.expect.element('@addSheetDialog').to.not.be.visible;
                    //new sheet should be added
                    canvass.expect.element('@sheet1').to.be.visible;
                    //new node should be present
                    canvass.expect.element('@nodeConstant2').to.be.visible;

                    callback();
                }
            ],
            function () {
                //Finished
            });
    },
    /**
     *  Test: 3-005
     *  Expects:
     *      - Selected nodes should be drawn in the new sheet. If there are links then it should be also drawn to the canvass of the new sheet.
     */
    "3-005": function (client) {
        async.series([
                //select Main Sheet
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        callback();
                    });
                },
                // select nodes in Main sheet
                function (callback) {
                    canvass.selectNodes(client, 'html > body > div#container > div#sheets > div:nth-of-type(1)', function(){
                        callback();
                    });
                },
                //create sheet from selected nodes
                function (callback) {
                    canvass.createSheetFromNodes(client, '#canvas2_MAIN > div:nth-of-type(1)', 'test2', function(){
                        callback();
                    });
                },
                //validate results
                function (callback) {
                    //dialog should be closed
                    canvass.expect.element('@addSheetDialog').to.not.be.visible;
                    //new sheet should be added
                    canvass.expect.element('@sheet2').to.be.visible;
                    //new node should be present
                    canvass.expect.element('@nodeConstant3').to.be.visible;
                    canvass.expect.element('@nodeInputStream2').to.be.visible;
                    canvass.expect.element('@nodeLOOP2').to.be.visible;

                    callback();
                }
            ],
            function () {
                //Finished
            });
    }
};