var async    = require('async');
var canvass;
module.exports = {
    '@tags': ['cf_help'],
    before: function (client) {
        client
            .url(client.launchUrl)
            .waitForElementVisible('body', 1000);
    },

    after: function (client) {
        client.end();
    },
    /**
     *  Test: 10-001
     *  Expects:
     *      - Hark Designer will be loaded in the browser.
     *      - Nodes and links should be drawn in the sheet.
     */
    "10-001": function (client) {
        async.series([
                //load HARK Designer
                function(callback){
                    canvass = client.page.canvass();
                    canvass.navigate();

                    //check if body is now visible
                    canvass.expect.element('body').to.be.present;

                    callback();

                    //should have Main sheet
                    canvass.expect.element('@mainSheet').to.be.visible;
                },
                //setup fixture
                function (callback) {
                    canvass.loadFixture(client, function () {
                        callback();
                    });
                },
                //check if nodeConstant1 is present in MAIN Sheet
                function(callback) {
                    //select MAIN sheet
                    canvass.selectSheet('@mainSheetTab', function () {
                        canvass.expect.element('@nodeConstant1').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-002
     *  Expects:
     *      - Context menu will appear
     */
    "10-002": function (client) {
        async.series([
                //select MAIN sheet
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        callback();
                    });
                },
                //mouse over nodeConstant1
                function (callback) {
                    client.moveToElement('#node_Constant_1', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    });
                },
                //context menu should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 1000, function () {
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-003
     *  Expects:
     *      - Dialog box will appear saying Hark Designer will open another page for the Documentation of the Constant node.
     *      - Pages will differ based on the node selected.
     *      - Page redirection will only apply on the default nodes.
     *      - This does not apply on dynamic nodes.
     */
    "10-003": function (client) {
        async.series([
                //there should be Help option
                function (callback) {
                    canvass.waitForElementPresent('@helpOption', 1000, function () {
                        callback();
                    })
                },
                //click Help option
                function (callback) {
                    canvass.click('@helpOption', function(){
                        callback();
                    });
                },
                //check if alert text is correct
                function (callback) {
                    client.getAlertText(function(alertText){
                        if(alertText) {
                            client.assert.equal(alertText.value, 'No help for this node.');
                        }
                        callback();
                    });
                },
                //close alert
                function (callback) {
                    client.acceptAlert(function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-004
     *  Expects:
     *      - Context menu will appear
     */
    "10-004": function (client) {
        async.series([
                //select LOOP sheet
                function (callback) {
                    canvass.selectSheet('@sheet1Tab', function () {
                        callback();
                    });
                },
                //mouse over on nodeLocalizeMUSIC1
                function (callback) {
                    client.moveToElement('#node_LocalizeMUSIC_1', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        canvass.api.pause(2000, function () {
                            callback();
                        });
                    });
                },
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 1000, function () {
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-005
     *  Expects:
     *      - Dialog box will appear saying Hark Designer will open another page for the Documentation of the Constant node.
     *      - Pages will differ based on the node selected.
     *      - Page redirection will only apply on the default nodes.
     *      - This does not apply on dynamic nodes.
     */
    "10-005": function (client) {
        async.series([
                //there should be Help option
                function (callback) {
                    canvass.waitForElementPresent('@helpOption', 1000, function () {
                        callback();
                    })
                },
                //click Help option
                function (callback) {
                    canvass.click('@helpOption', function(){
                        callback();
                    });
                },
                //check if alert text is correct
                function (callback) {
                    client.getAlertText(function(alertText){
                        if(alertText) {
                            client.assert.equal(alertText.value, 'Hark Designer is opening the web page of http://www.hark.jp/document/hark-document-en/subsec-LocalizeMUSIC.html. OK?');
                        }

                        callback();
                    });
                },
                //close alert
                function (callback) {
                    client.dismissAlert(function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-006
     *  Expects:
     *      - Context menu will appear
     */
    "10-006": function (client) {
        async.series([
                //select MAIN sheet
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        callback();
                    });
                },
                //mouse over on nodeLOOP1
                function (callback) {
                    client.moveToElement('#node_LOOP_1', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    });
                },
                function (callback) {
                    client.pause(1000, function () {
                        callback();
                    });
                },
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 1000, function () {
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 10-007
     *  Expects:
     *      - Dialog box will appear saying there is no help for this node.
     */
    "10-007": function (client) {
        async.series([
                //there should be Help option
                function (callback) {
                    canvass.waitForElementPresent('@helpOption', 1000, function () {
                        callback();
                    })
                },
                //click Help option
                function (callback) {
                    canvass.click('@helpOption', function(){
                        callback();
                    });
                },
                //check if alert text is correct
                function (callback) {
                    client.getAlertText(function(alertText){
                        if(alertText) {
                            client.assert.equal(alertText.value, 'No help for this node.');
                        }
                        callback();
                    });
                },
                //close alert
                function (callback) {
                    client.acceptAlert(function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    }
};
