import unittest
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import harkdesigner


class PythonNode (harkdesigner.TestHarkDesigner):
    def test_param(self):
        # setup

        expects = {
            "string": [True, True, True, True, True],
            "int": [True, True, True, False, False],
            "float": [True, True, True, False, False],
            "bool": [True, True, False],
            "object": [True, True, True, False, False]
        }
        testdata = {
            "string": ["abc", 3.5, -3, "%%%", "---"],
            "int": [-100, 0, 100, 0.5, "abc"],
            "float": [-10, 0.5, 100.0, "abc", "def"],
            "bool": ["true", "false", "abc"],
            "object": ["<Vector <int> 3>", "<Vector <float> >",
                       "<Vector <int> >", "aaa",
                       "<Vector <int>>"]
        }
        nodeid = "node_Constant_1"

        # Are parameters applied?
        self.addNode("Constant")
        for typ in ["string", "int", "float", "bool", "object"]:
            for val, expect in zip(testdata[typ], expects[typ]):
                self.openParam(nodeid)
                self.setParamType(nodeid, "VALUE", typ, True)
                self.setParamValue(nodeid, "VALUE", val, True)
                self.assertParamType(nodeid, "VALUE", typ)
                self.closeParam(nodeid)

                if expect:
                    self.assertParamValue(nodeid, "VALUE", val)
                else:
                    self.assertParamValueError()
        self.delNode(nodeid)

        # Are parameters not applied?
        self.addNode("Constant")
        for typ in ["string", "int", "float", "bool", "object"]:
            for val, expect in zip(testdata[typ], expects[typ]):
                self.openParam(nodeid)
                self.setParamType(nodeid, "VALUE", typ, True)
                self.setParamValue(nodeid, "VALUE", val, True)
                self.assertParamType(nodeid, "VALUE", typ)
                self.closeParam(nodeid, "cancel")

                if expect:
                    if not typ == "bool":
                        self.assertNotParamValue(nodeid, "VALUE", val)
                else:
                    self.assertParamValueError()
        self.delNode(nodeid)

    def test_subnetparam(self):
        self.addSheet("LOOP0")
        self.addNode("LOOP0")

        # is data and name copied?
        teststring = "ffdkslajfdksla"
        constid = "node_Constant_1"
        loop0id = "node_LOOP0_1"

        self.activateSheet("LOOP0")
        self.addNode("Constant")
        self.openParam(constid)
        self.setParamType(constid, "VALUE", "string", True)
        self.setParamValue(constid, "VALUE", teststring, True)
        self.closeParam(constid)

        val = self.getParamValue(constid, "VALUE")
        self.setParamType(constid, "VALUE", "subnet_param")
        self.assertParamType(constid, "VALUE", "subnet_param")

        self.activateSheet("MAIN")
        self.assertParamType(loop0id, "VALUE", "string")
        self.assertParamValue(loop0id, "VALUE", val)

        # subnet_param name change
        self.activateSheet("LOOP0")
        self.setParamValue(constid, "VALUE", teststring)
        self.activateSheet("MAIN")
        self.assertParamValue(loop0id, teststring, teststring)

        # nodedefs check
        self.addNode("LOOP0")
        self.assertParamType("node_LOOP0_2", teststring, "string")

if __name__ == "__main__":
    unittest.main()
